@@ -649,13 +649,13 @@ void Buffer::setHideLineChanged(bool isHide, size_t location)
 {
 	//First run through all docs without removing markers
 	for (int i = 0; i < _references; ++i)
-		_referees.at(i)->notifyMarkers(this, isHide, location, false); // (i == _references-1));
+		_referees.at(i)->notifyHidelineMarkers(this, isHide, location, false); // (i == _references-1));
 
 	if (!isHide) // no deleting if hiding lines
 	{
 		//Then all docs to remove markers.
 		for (int i = 0; i < _references; ++i)
-			_referees.at(i)->notifyMarkers(this, isHide, location, true);
+			_referees.at(i)->notifyHidelineMarkers(this, isHide, location, true);
 	}
 }
 
@@ -1079,7 +1079,7 @@ For existing file (c:\tmp\foo.h)
 	- Editing
 	when a file starts being modified, a file will be created with name: FILENAME@CREATION_TIMESTAMP (backup\foo.h@198776)
 	the Buffer object will associate with this FILENAME@CREATION_TIMESTAMP file (backup\foo.h@198776).
-	1. sync: (each 3-5 second) backup file will be saved, if buffer is dirty, and modification is present (a bool on modified notificatin).
+	1. sync: (every N seconds) the backup file will be saved if the buffer is dirty and modifications are present. A boolean flag is set to true upon modification notification, and it's set to false after the backup file is saved.
 	2. sync: each save file, or close file, the backup file will be deleted (if buffer is not dirty).
 	3. before switch off to another tab (or close files on exit), check 1 & 2 (sync with backup).
 
@@ -1088,22 +1088,22 @@ For existing file (c:\tmp\foo.h)
 	1. track FILENAME@CREATION_TIMESTAMP (backup\foo.h@198776) if exist (in session.xml).
 	2. track last modified timestamp of FILENAME (c:\tmp\foo.h) if FILENAME@CREATION_TIMESTAMP (backup\foo.h@198776) was tracked  (in session.xml).
 
-For untitled document (new  4)
+For untitled document (new 4)
 	- Open
 	In the next session, Notepad++
-	1. open file UNTITLED_NAME@CREATION_TIMESTAMP (backup\new  4@198776)
-	2. set label as UNTITLED_NAME (new  4) and disk icon as red.
+	1. open file UNTITLED_NAME@CREATION_TIMESTAMP (backup\new 4@198776)
+	2. set label as UNTITLED_NAME (new 4) and disk icon as red.
 
 	- Editing
-	when a untitled document starts being modified, a backup file will be created with name: UNTITLED_NAME@CREATION_TIMESTAMP (backup\new  4@198776)
-	the Buffer object will associate with this UNTITLED_NAME@CREATION_TIMESTAMP file (backup\new  4@198776).
-	1. sync: (each 3-5 second) backup file will be saved, if buffer is dirty, and modification is present (a bool on modified notificatin).
+	when a untitled document starts being modified, a backup file will be created with name: UNTITLED_NAME@CREATION_TIMESTAMP (backup\new 4@198776)
+	the Buffer object will associate with this UNTITLED_NAME@CREATION_TIMESTAMP file (backup\new 4@198776).
+	1. Sync: (every N seconds) the backup file will be saved if the buffer is dirty and modifications are present. A boolean flag is set to true upon modification notification, and it's set to false after the backup file is saved.
 	2. sync: if untitled document is saved, or closed, the backup file will be deleted.
 	3. before switch off to another tab (or close documents on exit), check 1 & 2 (sync with backup).
 
-	- CLOSE
+	- Close
 	In the current session, Notepad++
-	1. track UNTITLED_NAME@CREATION_TIMESTAMP (backup\new  4@198776) in session.xml.
+	1. track UNTITLED_NAME@CREATION_TIMESTAMP (backup\new 4@198776) in session.xml.
 */
 
 std::mutex backup_mutex;
@@ -1223,6 +1223,8 @@ bool FileManager::backupCurrentBuffer()
 
 					buffer->setTabCreatedTimeStringFromBakFile();
 
+					buffer->setModifiedStatus(false);
+
 					result = true;	//all done
 				}
 			}
@@ -1245,14 +1247,11 @@ bool FileManager::backupCurrentBuffer()
 			// Session changes, save it
 			hasModifForSession = true;
 		}
-		//printStr(L"backup deleted in backupCurrentBuffer"));
 		result = true; // no backup file to delete
 	}
-	//printStr(L"backup sync"));
 
 	if (result && hasModifForSession)
 	{
-		//printStr(buffer->getBackupFileName().c_str());
 		_pNotepadPlus->saveCurrentSession();
 	}
 	return result;
